@@ -30,7 +30,7 @@ class SVGPRegressionModel(ApproximateGP):
     def __init__(self, inducing_points, distribution_cls):
         variational_distribution = distribution_cls(inducing_points.size(-1))
         variational_strategy = gpytorch.variational.VariationalStrategy(
-            self, inducing_points, variational_distribution, learn_inducing_locations=True
+            self, inducing_points, variational_distribution, learn_inducing_locations=True, jitter_val=1e-4
         )
         super(SVGPRegressionModel, self).__init__(variational_strategy)
         self.mean_module = gpytorch.means.ConstantMean()
