@@ -9,16 +9,15 @@ import gpytorch
 
 class TestGrid(unittest.TestCase):
     def test_scale_to_bounds(self):
-        """
-        """
+        """ """
         x = torch.randn(100) * 50
-        res = gpytorch.utils.grid.scale_to_bounds(x, -1, 1)
-        self.assertGreater(res.min().item(), -1)
-        self.assertLess(res.max().item(), 1)
+        scale_module = gpytorch.utils.grid.ScaleToBounds(-1.0, 1.0)
+        res = scale_module(x)
+        self.assertGreater(res.min().item(), -1.0)
+        self.assertLess(res.max().item(), 1.0)
 
     def test_choose_grid_size(self):
-        """
-        """
+        """ """
         x = torch.randn(100)
         grid_size = gpytorch.utils.grid.choose_grid_size(x, ratio=2.0)
         self.assertEqual(grid_size, 200)
